Installation
============

Dependencies
------------

Requirements:
    * Python 2.x (x>=6) or 3.x (x>=2)
    * PyQt4 4.x (x>=3 ; recommended x>=4) or PyQt5 5.x (x>=5)
    * NumPy 1.x (x>=5)
    * Sphinx 1.x (x>=1) for documentation generation

Installation
------------

From the source package:

    `python setup.py install`

Help and support
----------------

External resources:

    * Bug reports and feature requests: `GitHub`_

.. _GitHub: https://github.com/PierreRaybaut/PythonQwt
